summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/transactionform.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/transactionform.h')
-rw-r--r--kmymoney2/widgets/transactionform.h68
1 files changed, 35 insertions, 33 deletions
diff --git a/kmymoney2/widgets/transactionform.h b/kmymoney2/widgets/transactionform.h
index 13116da..5c50248 100644
--- a/kmymoney2/widgets/transactionform.h
+++ b/kmymoney2/widgets/transactionform.h
@@ -21,12 +21,12 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qtable.h>
-#include <qvaluelist.h>
-#include <qvaluevector.h>
-#include <qpalette.h>
-#include <qwidgetlist.h>
-#include <qtabbar.h>
+#include <tqtable.h>
+#include <tqvaluelist.h>
+#include <tqvaluevector.h>
+#include <tqpalette.h>
+#include <tqwidgetlist.h>
+#include <tqtabbar.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -47,9 +47,10 @@ namespace KMyMoneyTransactionForm {
/**
* @author Thomas Baumgart
*/
-class TabBar : public QTabBar
+class TabBar : public TQTabBar
{
Q_OBJECT
+ TQ_OBJECT
public:
typedef enum {
SignalNormal = 0, // standard signal behaviour
@@ -57,18 +58,18 @@ public:
SignalAlways // always signal selection of a tab
} SignalEmissionE;
- TabBar(QWidget* parent = 0, const char* name = 0);
+ TabBar(TQWidget* tqparent = 0, const char* name = 0);
virtual ~TabBar() {}
SignalEmissionE setSignalEmission(SignalEmissionE type);
void copyTabs(const TabBar* otabbar);
- void addTab(QTab* tab, int id);
+ void addTab(TQTab* tab, int id);
- void setIdentifier(QTab* tab, int newId);
+ void setIdentifier(TQTab* tab, int newId);
- QTab* tab(int id) const;
+ TQTab* tab(int id) const;
int currentTab(void) const;
@@ -81,7 +82,7 @@ public slots:
/**
* overridden for internal reasons, API not changed
*/
- virtual void setCurrentTab( QTab * );
+ virtual void setCurrentTab( TQTab * );
/**
* overridden for internal reasons, API not changed
@@ -100,10 +101,10 @@ private:
/**
* maps our internal action ids to those used by
* qt3. Since it does not seem possible to tell
- * qt3 to use our ids everywhere (in QAccel) we
+ * qt3 to use our ids everywhere (in TQAccel) we
* need to know which is which
*/
- QMap<int, int> m_idMap;
+ TQMap<int, int> m_idMap;
};
@@ -123,34 +124,35 @@ typedef enum {
class TransactionForm : public TransactionEditorContainer
{
Q_OBJECT
+ TQ_OBJECT
public:
- TransactionForm(QWidget *parent = 0, const char *name = 0);
+ TransactionForm(TQWidget *tqparent = 0, const char *name = 0);
virtual ~TransactionForm() {}
/**
- * Override the QTable member function to avoid display of focus
+ * Override the TQTable member function to avoid display of focus
*/
- void paintFocus(QPainter* /*p*/, const QRect& /*cr*/ ) {}
+ void paintFocus(TQPainter* /*p*/, const TQRect& /*cr*/ ) {}
- QSize tableSize(void) const;
- QSize sizeHint(void) const;
+ TQSize tableSize(void) const;
+ TQSize tqsizeHint(void) const;
void adjustColumn(Column col);
void clear(void);
- void paintCell(QPainter* painter, int row, int col, const QRect& r, bool selected, const QColorGroup& cg);
+ void paintCell(TQPainter* painter, int row, int col, const TQRect& r, bool selected, const TQColorGroup& cg);
void resize(int col);
- void arrangeEditWidgets(QMap<QString, QWidget*>& editWidgets, KMyMoneyRegister::Transaction* t);
- void removeEditWidgets(QMap<QString, QWidget*>& editWidgets);
- void tabOrder(QWidgetList& tabOrderWidgets, KMyMoneyRegister::Transaction* t) const;
+ void arrangeEditWidgets(TQMap<TQString, TQWidget*>& editWidgets, KMyMoneyRegister::Transaction* t);
+ void removeEditWidgets(TQMap<TQString, TQWidget*>& editWidgets);
+ void tabOrder(TQWidgetList& tabOrderWidgets, KMyMoneyRegister::Transaction* t) const;
/**
* reimplemented to prevent normal cell selection behavior
*/
void setCurrentCell(int, int) {}
- TabBar* tabBar(QWidget* parent = 0);
+ TabBar* tabBar(TQWidget* tqparent = 0);
void setupForm(const MyMoneyAccount& acc);
@@ -158,37 +160,37 @@ public:
protected:
/**
* reimplemented to support QWidget::WState_BlockUpdates
*/
- void drawContents(QPainter *p, int cx, int cy, int cw, int ch);
+ void drawContents(TQPainter *p, int cx, int cy, int cw, int ch);
/**
* reimplemented to prevent normal mouse press behavior
*/
- void contentsMousePressEvent(QMouseEvent* ev) { ev->ignore(); }
+ void contentsMousePressEvent(TQMouseEvent* ev) { ev->ignore(); }
/**
* reimplemented to prevent normal mouse move behavior
*/
- void contentsMouseMoveEvent(QMouseEvent* ev) { ev->ignore(); }
+ void contentsMouseMoveEvent(TQMouseEvent* ev) { ev->ignore(); }
/**
* reimplemented to prevent normal mouse release behavior
*/
- void contentsMouseReleaseEvent(QMouseEvent* ev) { ev->ignore(); }
+ void contentsMouseReleaseEvent(TQMouseEvent* ev) { ev->ignore(); }
/**
* reimplemented to prevent normal mouse double click behavior
*/
- void contentsMouseDoubleClickEvent(QMouseEvent* ev) { ev->ignore(); }
+ void contentsMouseDoubleClickEvent(TQMouseEvent* ev) { ev->ignore(); }
/**
* reimplemented to prevent normal keyboard behavior
*/
- void keyPressEvent(QKeyEvent* ev) { ev->ignore(); }
+ void keyPressEvent(TQKeyEvent* ev) { ev->ignore(); }
/**
- * Override logic and use standard QFrame behaviour
+ * Override logic and use standard TQFrame behaviour
*/
bool focusNextPrevChild(bool next);
@@ -212,7 +214,7 @@ signals:
protected:
KMyMoneyRegister::Transaction* m_transaction;
- QColorGroup m_cellColorGroup;
+ TQColorGroup m_cellColorGroup;
TabBar* m_tabBar;
};
@@ -158,37 +160,37 @@ public:
protected:
/**
- * reimplemented to support QWidget::WState_BlockUpdates
+ * reimplemented to support TQWidget::WState_BlockUpdates
*/